==> openshift-model-hive-5.12.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterImageSetBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterImageSetBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterImageSetFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterImageSetBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterImageSet,io.fabric8.openshift.api.model.hive.v1.ClusterImageSetBuilder>{
  public ClusterImageSetBuilder() {
    this(false);
  }
  public ClusterImageSetBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterImageSet(), validationEnabled);
  }
  public ClusterImageSetBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterImageSetFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterImageSetBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterImageSetFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterImageSet(), validationEnabled);
  }
  public ClusterImageSetBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterImageSetFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterImageSet instance) {
    this(fluent, instance, false);
  }
  public ClusterImageSetBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterImageSetFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterImageSet instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterImageSetBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterImageSet instance) {
    this(instance,false);
  }
  public ClusterImageSetBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterImageSet instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterImageSetFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterImageSet build() {
    ClusterImageSet buildable = new ClusterImageSet(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterImageSetBuilder that = (ClusterImageSetBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.6.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterImageSetBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterImageSetBuilder extends ClusterImageSetFluentImpl<ClusterImageSetBuilder> implements VisitableBuilder<ClusterImageSet,ClusterImageSetBuilder>{
  public ClusterImageSetBuilder() {
    this(false);
  }
  public ClusterImageSetBuilder(Boolean validationEnabled) {
    this(new ClusterImageSet(), validationEnabled);
  }
  public ClusterImageSetBuilder(ClusterImageSetFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterImageSetBuilder(ClusterImageSetFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterImageSet(), validationEnabled);
  }
  public ClusterImageSetBuilder(ClusterImageSetFluent<?> fluent,ClusterImageSet instance) {
    this(fluent, instance, false);
  }
  public ClusterImageSetBuilder(ClusterImageSetFluent<?> fluent,ClusterImageSet instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterImageSetBuilder(ClusterImageSet instance) {
    this(instance,false);
  }
  public ClusterImageSetBuilder(ClusterImageSet instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterImageSetFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterImageSet build() {
    ClusterImageSet buildable = new ClusterImageSet(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
